@@ -56,8 +56,8 @@ const STATE_FAILED          = "failed";
 // From updater/errors.h:
 const WRITE_ERROR = 7;
 
-const DOWNLOAD_CHUNK_SIZE           = 65536;
-const DOWNLOAD_BACKGROUND_INTERVAL  = 60;  // seconds
+const DOWNLOAD_CHUNK_SIZE           = 300000; // bytes
+const DOWNLOAD_BACKGROUND_INTERVAL  = 600;    // seconds
 const DOWNLOAD_FOREGROUND_INTERVAL  = 0;
 
 // Values for the PREF_APP_UPDATE_INCOMPATIBLE_MODE pref. See documentation in
