@@ -1,24 +1,23 @@
-//@line 38 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 38 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
 
-//@line 41 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 41 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
 var helpFileURI;
 
-//@line 46 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 46 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
 function openHelp(topic, contentPack)
 {
-  dump("WWWWWWEEEEEEEEEEE'RRRRRRE HERE\n");
-//@line 51 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 50 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
   helpFileURI = contentPack || helpFileURI;
 
-//@line 54 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 53 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
   var topWindow = locateHelpWindow(helpFileURI);
 
   if ( topWindow ) {
-//@line 58 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 57 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
     topWindow.focus();
     topWindow.displayTopic(topic);
   } else {
-//@line 62 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 61 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
     const params = Components.classes["@mozilla.org/embedcomp/dialogparam;1"]
                              .createInstance(Components.interfaces.nsIDialogParamBlock);
     params.SetNumberStrings(2);
@@ -30,13 +29,13 @@ function openHelp(topic, contentPack)
   }
 }
 
-//@line 74 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 73 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
 function setHelpFileURI(rdfURI)
 {
   helpFileURI = rdfURI;
 }
 
-//@line 80 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 79 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
 function locateHelpWindow(contentPack) {
     const windowManagerInterface = Components
         .classes['@mozilla.org/appshell/window-mediator;1'].getService()
@@ -45,7 +44,7 @@ function locateHelpWindow(contentPack) {
     var topWindow = null;
     var aWindow;
 
-//@line 90 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
+//@line 89 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/contextHelp.js"
     while (iterator.hasMoreElements()) {
         aWindow = iterator.getNext();
         if (aWindow.getHelpFileURI() == contentPack) {
